libscientific python binding
============================

This is a foreign function python binding of libscientific.

Libscientific is a C framework  for multivariate and other statistical analysis.
This library is capable to run:

- Principal component analysis using the NIPALS algorithm
- Partial Least Squares using the NIPALS algorithm
- Multiple Linear Regression using the Ordinary Least Squares algorithm
- Fisher Linear Discrimnant Analysis 
- KMeans and Hierarchical clustering
- Matrix/vector/tensor operations (products, matrix inversions using the Gauss-Jordan algorithm, and so on)
- Descriptive statistics for regression and classification problems.
- Model validation with leave-one-out and Bootstrap random kfold cross validation
- Variable selection using genetic and metaheuristic algorithms
- Solve linear system of equations 
- Interpolate curves usin the natural cubic spline algorithm


More information at

- https://github.com/gmrandazzo/libscientific
- http://gmrandazzo.github.io/libscientific/Source/_build/html/GettingStartedInPython.html

License
=======

libscientific and libscientific python binding is distributed under GPLv3 license.

To know more in details how the licens work please
go to "http://www.gnu.org/licenses/gpl-3.0.en.html"

libscientific is currently mantained by Giuseppe Marco Randazzo.
